@@ -4,8 +4,8 @@ A simple in-process python `scheduler` library for `datetime` objects.
 Author: Jendrik A. Potyka, Fabian A. Preiss
 """
 
-__version__ = "0.6.3"
+__version__ = "0.7.2"
 __author__ = "Jendrik A. Potyka, Fabian A. Preiss"
 
-from scheduler.core import Scheduler
-from scheduler.util import SchedulerError
+from scheduler.error import SchedulerError
+from scheduler.threading.scheduler import Scheduler
